#[non_exhaustive]pub enum Request<'a> {
Create {},
Destroy,
}Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Create
create a transient seat
Create a new seat that is removed when the client side transient seat object is destroyed.
The actual seat may be removed sooner, in which case the transient seat object shall become inert.
Destroy
destroy the manager
Destroy the manager.
All objects created by the manager will remain valid until they are destroyed themselves.
This is a destructor, once sent this object cannot be used any longer.
Implementations